from typing import Final

class GaiaDefaultTutorialSite:
    class InitTutorial1:
        UUID: Final[str] = "c42edc7f-f382-40c6-b042-68858daa8ec3"
    class InitTutorial2:
        UUID: Final[str] = "26630f2f-ab60-417f-bae9-a3cb7385692f"
    class InitTutorialEnd:
        UUID: Final[str] = "5a2edb29-5d2b-49af-8456-57e332a33e8f"
